@@ -67,12 +67,42 @@ log_exception <- function(
 #'   as `integer` (invisibly)
 #'
 #' @export
+#'
+#'
+#' @examples
+#' # Get and set the threshold of the root logger
+#' threshold("error")
+#' threshold()
+#' lgr$info("this will be supressed")
+#' lgr$error("an important error message")
+#'
+#' # you can also specify a target to modify other loggers
+#' lg <- get_logger("test")
+#' threshold("fatal", target = lg)
+#' threshold(target = lg)
+#'
+#' # If a Logger's threshold is not set, the threshold is inherited from
+#' # its parent, in this case the root logger (that we set to error/200 before)
+#' threshold(NULL, target = lg)
+#' threshold(target = lg)
+#'
+#' # Alternative R6 API for getting/setting thresholds
+#' lg$set_threshold("info")
+#' lg$threshold
+#' lg$set_threshold(300)
+#' lg$threshold
+#' lg$set_threshold(NULL)
+#' lg$threshold
+#'
+#' # cleanup
+#' lgr$config(NULL)
+#' lg$config(NULL)
 threshold <- function(
   level,
   target = lgr::lgr
 ){
   if (missing(level))
-    target$threshold
+    return(target[["threshold"]])
   else
     target$set_threshold(level)
 
@@ -106,6 +136,9 @@ console_threshold <- function(
 #' @return `add_appender()` and `remove_appender()` return `target`.
 #' @export
 #' @examples
+#'
+#'
+#' # add Appenders to a Logger
 #' add_appender(AppenderConsole$new(), "second_console_appender")
 #' lgr$fatal("Multiple console appenders are a bad idea")
 #' remove_appender("second_console_appender")
@@ -173,7 +206,8 @@ remove_appender <- function(
 #' show_log()
 #' show_data()
 #'
-#'
+#' # cleanup
+#' lgr$config(NULL)
 show_log <- function(
   threshold = NA_integer_,
   n = 20L,
